@@ -1,25 +1,14 @@
-/*
-* Copyright (C) 2019 ~ 2020 UnionTech Software Technology Co.,Ltd
-*
-* Author:     zyc <zyc@uniontech.com>
-* Maintainer:  zyc <zyc@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logcollectormain.h"
 #include "DebugTimeManager.h"
 #include "ut_stuballthread.h"
 #include "logapplication.h"
 #include "utils.h"
+#include "ut_stubpublic.h"
+#include "logapplicationhelper.h"
 #include <stub.h>
 
 #include <DTitlebar>
@@ -94,6 +83,7 @@ TEST(LogCollectorMain_Constructor_UT, LogCollectorMain_Constructor_UT)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
     p->deleteLater();
@@ -112,6 +102,7 @@ TEST(LogCollectorMain_Destructor_UT, LogCollectorMain_Destructor_UT)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
     p->~LogCollectorMain();
@@ -131,6 +122,7 @@ TEST(LogCollectorMain_initUI_UT, LogCollectorMain_initUI_UT)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
     p->deleteLater();
@@ -149,6 +141,7 @@ TEST(LogCollectorMain_initShortCut_UT, LogCollectorMain_initShortCut_UT_001)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
     p->initShortCut();
@@ -168,6 +161,7 @@ TEST(LogCollectorMain_initShortCut_UT, LogCollectorMain_initShortCut_UT_002)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
     p->m_scWndReize->deleteLater();
@@ -196,6 +190,7 @@ TEST(LogCollectorMain_initConnection_UT, LogCollectorMain_initConnection_UT)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
 
@@ -265,6 +260,7 @@ TEST_P(LogCollectorMain_handleApplicationTabEventNotify_UT, LogCollectorMain_han
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain_handleApplicationTabEventNotify_UT_Param param = GetParam();
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
@@ -291,6 +287,7 @@ TEST_P(LogCollectorMain_handleApplicationTabEventNotify_UT, LogCollectorMain_han
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
     stub.set(ADDR(QObject, objectName), stub_ObjectName);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     LogCollectorMain_handleApplicationTabEventNotify_UT_Param param = GetParam();
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     EXPECT_NE(p, nullptr);
@@ -316,12 +313,13 @@ TEST(LogCollectorMain_switchRefreshActionTriggered_UT, LogCollectorMain_switchRe
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
-
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     typedef  bool (*fptr)(LogApplication *);
     fptr test = (fptr)(&LogApplication::notify);
     stub.set(test, LogCollectorMain_notify);
     LogCollectorMain *p = new LogCollectorMain(nullptr);
     ASSERT_TRUE(p);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QAction *action = new QAction(qApp->translate("titlebar", "5 min"));
     stub.set(ADDR(QList<QAction *>, indexOf), LogCollectorMain_int);
     p->switchRefreshActionTriggered(action);
@@ -329,6 +327,7 @@ TEST(LogCollectorMain_switchRefreshActionTriggered_UT, LogCollectorMain_switchRe
         p->m_refreshTimer->stop();
     }
     delete action;
+#endif
     p->deleteLater();
 }
 
@@ -345,6 +344,7 @@ TEST(LogCollectorMain_exportAllLogs_UT, LogCollectorMain_exportAllLogs_UT_001)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     typedef  bool (*fptr)(LogApplication *);
     fptr test = (fptr)(&LogApplication::notify);
     stub.set(test, LogCollectorMain_notify);
@@ -368,6 +368,7 @@ TEST(LogCollectorMain_exportAllLogs_UT, LogCollectorMain_exportAllLogs_UT_002)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     typedef  bool (*fptr)(LogApplication *);
     fptr test = (fptr)(&LogApplication::notify);
     stub.set(test, LogCollectorMain_notify);
@@ -398,6 +399,7 @@ TEST(LogCollectorMain_closeEvent_UT, LogCollectorMain_closeEvent_UT_001)
     stub.set(ADDR(LogFileParser, parseByApp), LogFileParser_parseByApp);
     stub.set(ADDR(LogFileParser, parseByNormal), LogFileParser_parseByNormal);
     stub.set(ADDR(LogFileParser, parseByKwin), LogFileParser_parseByKwin);
+    stub.set(ADDR(LogApplicationHelper, getCustomLogList), LogApplicationHelper_getCustomLogList);
     typedef  bool (*fptr)(LogApplication *);
     fptr test = (fptr)(&LogApplication::notify);
     stub.set(test, LogCollectorMain_notify);
